========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/mistral.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

Mistral
=======

Workflow Service for OpenStack cloud. This project aims to provide a mechanism
to define tasks and workflows without writing code, manage and execute them in
the cloud environment.

Project Resources
-----------------

* `Mistral Official Documentation <https://docs.openstack.org/mistral/latest/>`_

    * `Installation Guide <https://docs.openstack.org/mistral/latest/install/installation_guide.html#>`_

    * `Configuration Guide <https://docs.openstack.org/mistral/latest/configuration/config-guide.html>`_

    * `Workflow Language Specification <https://docs.openstack.org/mistral/latest/user/wf_lang_v2.html>`_

* Project status, bugs, and blueprints are tracked on
  `Launchpad <https://launchpad.net/mistral/>`_

* CloudFlow: visualization tool for workflow executions on https://github.com/nokia/CloudFlow

* Additional resources are linked from the project
  `Wiki <https://wiki.openstack.org/wiki/Mistral/>`_ page

* Apache License Version 2.0 http://www.apache.org/licenses/LICENSE-2.0

* Release notes for the project can be found at:
  https://docs.openstack.org/releasenotes/mistral/
